@@ -60,8 +60,6 @@ from PyQt4 import QtGui
 from PyQt4.uic import loadUi
 
 
-
-
 class MainWindow(QtGui.QMainWindow):
     def __init__(self, parent=None):
         QtGui.QMainWindow.__init__(self,parent)
@@ -147,7 +145,7 @@ class MainWindow(QtGui.QMainWindow):
     
     
     def about(self):
-        webbrowser.open("http://www.craveo.de")             
+        webbrowser.open("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=XB3GQJH5XQ2AL")             
                  
     def hideui(self):
         #print"Fullscreen activated"
